# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: stats/per_possession_stats.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'stats/per_possession_stats.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n stats/per_possession_stats.proto\x12\tapi.stats\"\xb9\x01\n\rAverageCounts\x12\r\n\x05pass_\x18\x01 \x01(\x02\x12\x0e\n\x06passed\x18\x02 \x01(\x02\x12\x0f\n\x07\x64ribble\x18\x03 \x01(\x02\x12\x1c\n\x14\x64ribble_continuation\x18\x04 \x01(\x02\x12\x0c\n\x04shot\x18\x05 \x01(\x02\x12\x0c\n\x04goal\x18\x06 \x01(\x02\x12\x0e\n\x06\x61ssist\x18\x07 \x01(\x02\x12\x10\n\x08\x61ssisted\x18\x08 \x01(\x02\x12\x0c\n\x04save\x18\t \x01(\x02\x12\x0e\n\x06\x61\x65rial\x18\n \x01(\x02\"\x85\x01\n\x12PerPossessionStats\x12\x30\n\x0e\x61verage_counts\x18\x01 \x01(\x0b\x32\x18.api.stats.AverageCounts\x12\x18\n\x10\x61verage_duration\x18\x02 \x01(\x02\x12\x14\n\x0c\x61verage_hits\x18\x03 \x01(\x02\x12\r\n\x05\x63ount\x18\x04 \x01(\x05')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'stats.per_possession_stats_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_AVERAGECOUNTS']._serialized_start=48
  _globals['_AVERAGECOUNTS']._serialized_end=233
  _globals['_PERPOSSESSIONSTATS']._serialized_start=236
  _globals['_PERPOSSESSIONSTATS']._serialized_end=369
# @@protoc_insertion_point(module_scope)
