# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: metadata/player_loadout.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'metadata/player_loadout.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dmetadata/player_loadout.proto\x12\x0c\x61pi.metadata\"\xd5\x04\n\rPlayerLoadout\x12\x13\n\x0bload_out_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x62\x61nner\x18\x02 \x01(\x05\x12\r\n\x05\x62oost\x18\x03 \x01(\x05\x12\x0b\n\x03\x63\x61r\x18\x04 \x01(\x05\x12\x16\n\x0egoal_explosion\x18\x05 \x01(\x05\x12\x0c\n\x04skin\x18\x06 \x01(\x05\x12\r\n\x05trail\x18\x07 \x01(\x05\x12\x0e\n\x06wheels\x18\x08 \x01(\x05\x12\x0f\n\x07version\x18\t \x01(\x05\x12\x0e\n\x06topper\x18\n \x01(\x05\x12\x0f\n\x07\x61ntenna\x18\x0b \x01(\x05\x12\x14\n\x0c\x65ngine_audio\x18\x0c \x01(\x05\x12\x15\n\ravatar_border\x18\x16 \x01(\x05\x12\x14\n\x0c\x62\x61nner_paint\x18\r \x01(\x05\x12\x13\n\x0b\x62oost_paint\x18\x0e \x01(\x05\x12\x11\n\tcar_paint\x18\x0f \x01(\x05\x12\x1c\n\x14goal_explosion_paint\x18\x10 \x01(\x05\x12\x12\n\nskin_paint\x18\x11 \x01(\x05\x12\x13\n\x0btrail_paint\x18\x12 \x01(\x05\x12\x14\n\x0cwheels_paint\x18\x13 \x01(\x05\x12\x14\n\x0ctopper_paint\x18\x14 \x01(\x05\x12\x15\n\rantenna_paint\x18\x15 \x01(\x05\x12\x15\n\rprimary_color\x18\x17 \x01(\x05\x12\x14\n\x0c\x61\x63\x63\x65nt_color\x18\x18 \x01(\x05\x12\x16\n\x0eprimary_finish\x18\x19 \x01(\x05\x12\x15\n\raccent_finish\x18\x1a \x01(\x05\x12\x19\n\x11\x62\x61nner_user_color\x18\x1b \x01(\x03\x12 \n\x18\x61vatar_border_user_color\x18\x1c \x01(\x03')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'metadata.player_loadout_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_PLAYERLOADOUT']._serialized_start=48
  _globals['_PLAYERLOADOUT']._serialized_end=645
# @@protoc_insertion_point(module_scope)
