# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: metadata/mutators.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'metadata/mutators.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17metadata/mutators.proto\x12\x0c\x61pi.metadata\"Q\n\x08Mutators\x12)\n\tball_type\x18\x01 \x01(\x0e\x32\x16.api.metadata.BallType\x12\x1a\n\x12game_mutator_index\x18\x02 \x01(\x05*M\n\x08\x42\x61llType\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x01\x12\x0e\n\nBASKETBALL\x10\x02\x12\x08\n\x04PUCK\x10\x03\x12\x0c\n\x08\x43UBEBALL\x10\x04\x12\x0c\n\x08\x42REAKOUT\x10\x05')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'metadata.mutators_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_BALLTYPE']._serialized_start=124
  _globals['_BALLTYPE']._serialized_end=201
  _globals['_MUTATORS']._serialized_start=41
  _globals['_MUTATORS']._serialized_end=122
# @@protoc_insertion_point(module_scope)
