# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: stats/rumble.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'stats/rumble.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12stats/rumble.proto\x12\tapi.stats\"X\n\x0bRumbleStats\x12\x31\n\x0crumble_items\x18\x01 \x03(\x0b\x32\x1b.api.stats.RumbleItemsUsage\x12\x16\n\x0epre_item_goals\x18\x02 \x01(\x05\"h\n\x10RumbleItemsUsage\x12 \n\x04item\x18\x01 \x01(\x0e\x32\x12.api.stats.PowerUp\x12\x0c\n\x04used\x18\x02 \x01(\x05\x12\x0e\n\x06unused\x18\x03 \x01(\x05\x12\x14\n\x0c\x61verage_hold\x18\x04 \x01(\x02*\xd7\x01\n\x07PowerUp\x12\x0f\n\x0b\x42\x41LL_FREEZE\x10\x01\x12\x17\n\x13\x42\x41LL_GRAPPLING_HOOK\x10\x02\x12\x0e\n\nBALL_LASSO\x10\x03\x12\x0c\n\x08\x42\x41TARANG\x10\x03\x12\x0f\n\x0b\x42\x41LL_SPRING\x10\x04\x12\x0f\n\x0b\x42\x41LL_VELCRO\x10\x05\x12\x12\n\x0e\x42OOST_OVERRIDE\x10\x06\x12\x0e\n\nCAR_SPRING\x10\x07\x12\x10\n\x0cGRAVITY_WELL\x10\x08\x12\x0e\n\nSTRONG_HIT\x10\t\x12\x0b\n\x07SWAPPER\x10\n\x12\x0b\n\x07TORNADO\x10\x0b\x1a\x02\x10\x01')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'stats.rumble_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_POWERUP']._loaded_options = None
  _globals['_POWERUP']._serialized_options = b'\020\001'
  _globals['_POWERUP']._serialized_start=230
  _globals['_POWERUP']._serialized_end=445
  _globals['_RUMBLESTATS']._serialized_start=33
  _globals['_RUMBLESTATS']._serialized_end=121
  _globals['_RUMBLEITEMSUSAGE']._serialized_start=123
  _globals['_RUMBLEITEMSUSAGE']._serialized_end=227
# @@protoc_insertion_point(module_scope)
