# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: stats/stats.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'stats/stats.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11stats/stats.proto\x12\tapi.stats\"\x8e\x01\n\nPossession\x12\x17\n\x0fpossession_time\x18\x01 \x01(\x01\x12\x11\n\tturnovers\x18\x02 \x01(\x05\x12\x1c\n\x14turnovers_on_my_half\x18\x03 \x01(\x05\x12\x1f\n\x17turnovers_on_their_half\x18\x04 \x01(\x05\x12\x15\n\rwon_turnovers\x18\x05 \x01(\x05\"\xfe\x02\n\x14PositionalTendencies\x12\x16\n\x0etime_on_ground\x18\x01 \x01(\x02\x12\x17\n\x0ftime_low_in_air\x18\x02 \x01(\x02\x12\x18\n\x10time_high_in_air\x18\x03 \x01(\x02\x12\x1e\n\x16time_in_defending_half\x18\x04 \x01(\x02\x12\x1e\n\x16time_in_attacking_half\x18\x05 \x01(\x02\x12\x1f\n\x17time_in_defending_third\x18\x06 \x01(\x02\x12\x1d\n\x15time_in_neutral_third\x18\x07 \x01(\x02\x12\x1f\n\x17time_in_attacking_third\x18\x08 \x01(\x02\x12\x18\n\x10time_behind_ball\x18\t \x01(\x02\x12\x1a\n\x12time_in_front_ball\x18\n \x01(\x02\x12\x16\n\x0etime_near_wall\x18\x0b \x01(\x02\x12\x16\n\x0etime_in_corner\x18\x0c \x01(\x02\x12\x14\n\x0ctime_on_wall\x18\r \x01(\x02\"e\n\x08\x41verages\x12\x15\n\raverage_speed\x18\x01 \x01(\x02\x12\x1c\n\x14\x61verage_hit_distance\x18\x02 \x01(\x02\x12$\n\x1c\x61verage_distance_from_center\x18\x03 \x01(\x02\"\xd6\x01\n\tHitCounts\x12\x12\n\ntotal_hits\x18\x01 \x01(\x05\x12\x13\n\x0btotal_goals\x18\x02 \x01(\x05\x12\x14\n\x0ctotal_passes\x18\x03 \x01(\x05\x12\x13\n\x0btotal_saves\x18\x04 \x01(\x05\x12\x13\n\x0btotal_shots\x18\x05 \x01(\x05\x12\x16\n\x0etotal_dribbles\x18\x06 \x01(\x05\x12\x1b\n\x13total_dribble_conts\x18\x07 \x01(\x05\x12\x15\n\rtotal_aerials\x18\x08 \x01(\x05\x12\x14\n\x0ctotal_clears\x18\t \x01(\x05\"]\n\x05Speed\x12\x1a\n\x12time_at_slow_speed\x18\x01 \x01(\x02\x12\x1b\n\x13time_at_super_sonic\x18\x02 \x01(\x02\x12\x1b\n\x13time_at_boost_speed\x18\x03 \x01(\x02\"\x85\x02\n\x12\x44\x65tailedCarryStats\x12\x1a\n\x12\x61verage_z_distance\x18\x01 \x01(\x02\x12\x1b\n\x13\x61verage_xy_distance\x18\x02 \x01(\x02\x12\x1f\n\x17\x61verage_ball_z_velocity\x18\x03 \x01(\x02\x12\x1c\n\x14variance_xy_distance\x18\x04 \x01(\x02\x12\x1b\n\x13variance_z_distance\x18\x05 \x01(\x02\x12 \n\x18variance_ball_z_velocity\x18\x06 \x01(\x02\x12\x1b\n\x13\x61verage_carry_speed\x18\x07 \x01(\x02\x12\x1b\n\x13\x64istance_along_path\x18\x08 \x01(\x02')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'stats.stats_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_POSSESSION']._serialized_start=33
  _globals['_POSSESSION']._serialized_end=175
  _globals['_POSITIONALTENDENCIES']._serialized_start=178
  _globals['_POSITIONALTENDENCIES']._serialized_end=560
  _globals['_AVERAGES']._serialized_start=562
  _globals['_AVERAGES']._serialized_end=663
  _globals['_HITCOUNTS']._serialized_start=666
  _globals['_HITCOUNTS']._serialized_end=880
  _globals['_SPEED']._serialized_start=882
  _globals['_SPEED']._serialized_end=975
  _globals['_DETAILEDCARRYSTATS']._serialized_start=978
  _globals['_DETAILEDCARRYSTATS']._serialized_end=1239
# @@protoc_insertion_point(module_scope)
